use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007004
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Arun
Base
CPAN
Class
DROLSKY
DROLSKY's
Dave
Exception
Kumar's
Leon
PayPal
Ricardo
Rolsky
Rolsky's
Signes
Timmermans
Uncatchable
autarch
automagic
drolsky
egid
esque
fawaka
isa
lib
namespace
param
refcount
rethrow
rjbs
runtime
stacktrace
stringifies
subclasses
uncatchable
